@@ -2,8 +2,8 @@ package Bread::Board::Dumper;
 BEGIN {
   $Bread::Board::Dumper::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Bread::Board::Dumper::VERSION = '0.22';
+BEGIN {
+  $Bread::Board::Dumper::VERSION = '0.23';
 }
 use Moose;
 
@@ -57,7 +57,7 @@ Bread::Board::Dumper
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -82,6 +82,10 @@ version 0.22
 This is a useful utility for dumping a clean view of a Bread::Board
 container.
 
+=head1 AUTHOR (actual)
+
+Daisuke Maki
+
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
@@ -90,19 +94,6 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Daisuke Maki
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2008-2011 Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
 Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
