@@ -2,8 +2,8 @@ package Bread::Board::GraphViz;
 BEGIN {
   $Bread::Board::GraphViz::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Bread::Board::GraphViz::VERSION = '0.22';
+BEGIN {
+  $Bread::Board::GraphViz::VERSION = '0.23';
 }
 use Moose;
 # ABSTRACT: visualize L<Bread::Board> dependency graphs
@@ -134,7 +134,7 @@ Bread::Board::GraphViz - visualize L<Bread::Board> dependency graphs
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -150,7 +150,7 @@ L<GraphViz>
 
 L<GraphViz::HasA>
 
-=head1 AUTHOR
+=head1 AUTHOR (actual)
 
 Jonathan Rockway - C<< <jrockway@cpan.org> >>
 
@@ -162,19 +162,6 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Jonathan Rockway - C<< <jrockway@cpan.org> >>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007-2011 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
 Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
