@@ -2,8 +2,8 @@ package Bread::Board::Service::Deferred;
 BEGIN {
   $Bread::Board::Service::Deferred::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Bread::Board::Service::Deferred::VERSION = '0.22';
+BEGIN {
+  $Bread::Board::Service::Deferred::VERSION = '0.23';
 }
 use Moose ();
 
@@ -96,7 +96,7 @@ Bread::Board::Service::Deferred
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -108,19 +108,6 @@ All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
-=head1 AUTHOR
-
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007-2011 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =for Pod::Coverage can
 isa
 meta
