@@ -2,8 +2,8 @@ package Bread::Board::Service::Inferred;
 BEGIN {
   $Bread::Board::Service::Inferred::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Bread::Board::Service::Inferred::VERSION = '0.22';
+BEGIN {
+  $Bread::Board::Service::Inferred::VERSION = '0.23';
 }
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
@@ -225,7 +225,7 @@ Bread::Board::Service::Inferred
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -249,19 +249,6 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2010-2011 Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
 Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
